Physics-Based Inverse Rendering Toolkit
=============================================

.. only:: not latex

    .. image:: teaser.png
        :width: 800px
        :align: center

.. toctree::
   :maxdepth: 1
   :caption: Core features

   core_intro
   core_install
   → GitHub <https://github.com/uci-rendering/inv-render-toolkit/>

.. toctree::
   :maxdepth: 1
   :caption: Forward rendering

   forward_intro

.. toctree::
   :maxdepth: 1
   :caption: Inverse rendering

   inverse_intro

.. toctree::
   :maxdepth: 1
   :caption: Plugin references

   plugin_refs
